expand method
Expands the panel to its maximum or default size.
Implementation
@override
void expand() {
if (!_collapsed) return;
_collapsed = false;
notifyListeners();
}
Expands the panel to its maximum or default size.
@override
void expand() {
if (!_collapsed) return;
_collapsed = false;
notifyListeners();
}