mouseCursor property
ButtonStateProperty<MouseCursor>
get
mouseCursor
Returns the mouse cursor appearance based on button state.
Implementation
ButtonStateProperty<MouseCursor> get mouseCursor;
Returns the mouse cursor appearance based on button state.
ButtonStateProperty<MouseCursor> get mouseCursor;