AdditiveAxisSize class

Sum of two AxisSizes.

Inheritance

Constructors

AdditiveAxisSize(AxisSize a, AxisSize b)
Creates an additive axis size.
const

Properties

a AxisSize
The left operand.
final
b AxisSize
The right operand.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double available) double
Resolves this size against the available cross-axis extent.
override
toString() String
A string representation of this object.
inherited

Operators

operator *(double factor) AxisSize
Scales this size by factor.
inherited
operator +(AxisSize other) AxisSize
Sum of two sizes.
inherited
operator -(AxisSize other) AxisSize
Difference of two sizes.
inherited
operator /(double factor) AxisSize
Divides this size by factor.
inherited
operator ==(Object other) bool
The equality operator.
inherited