AnimatableValue<T> constructor

AnimatableValue<T>({
  1. required T start,
  2. required T end,
  3. required T lerp(
    1. T a,
    2. T b,
    3. double t
    ),
})

A class that represents an animatable value with a start and end value, and a function to interpolate between them.

The start parameter specifies the initial value of the animation. The end parameter specifies the final value of the animation. The lerp parameter is a function that defines how to interpolate between the start and end values.

Implementation

AnimatableValue({required this.start, required this.end, required this.lerp});