end property
T
end
final
The ending value of the animation.
This represents the final state that the animation will reach when it completes.
Implementation
final T end;
The ending value of the animation.
This represents the final state that the animation will reach when it completes.
final T end;