start property
T
start
final
The starting value of the animation.
This represents the initial state or value from which the animation begins.
Implementation
final T start;
The starting value of the animation.
This represents the initial state or value from which the animation begins.
final T start;