shouldTick property

bool get shouldTick

Checks if there are pending animations or an active runner.

Returns

true if animations should continue to be ticked, false otherwise.

Example

if (controller.shouldTick) {
  controller.tick(deltaTime);
}

Implementation

bool get shouldTick => _runner != null || _requests.isNotEmpty;