AnimationRunner class

Manages the execution of a single animation step.

This class tracks the progress of an animation from a start value to an end value over a specified duration using a curve.

Overview

AnimationRunner is used internally by AnimationQueueController to execute individual animation steps. It tracks progress and computes intermediate values.

Example

final runner = AnimationRunner(
  0.0, // from
  1.0, // to
  Duration(milliseconds: 200),
  Curves.easeIn,
);

Constructors

AnimationRunner(double from, double to, Duration duration, Curve curve)
Creates an animation runner with the specified parameters.

Properties

curve Curve
The easing curve applied to the animation.
final
duration Duration
The total duration of the animation.
final
from double
The starting value of the animation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to double
The ending value of the animation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited