asVerticalAlignment method
Converts this alignment to a standard Alignment with this as the vertical component.
Parameters:
crossAxisAlignment(AxisAlignment, required): The horizontal alignment component.
Returns: An Alignment combining this vertical alignment with the given horizontal alignment.
Implementation
Alignment asVerticalAlignment(AxisAlignment crossAxisAlignment) {
return Alignment(crossAxisAlignment.value, resolveValue(Axis.vertical));
}