AxisAlignmentDirectional class

Directional alignment along an axis.

Values range from -1.0 (start) to 1.0 (end).

Inheritance

Constructors

AxisAlignmentDirectional(double value)
Creates an AxisAlignmentDirectional.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The alignment value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection textDirection) AxisAlignment
Resolves the alignment to a concrete AxisAlignment based on the text direction.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

center → const AxisAlignmentDirectional
Alignment to the center (0.0).
end → const AxisAlignmentDirectional
Alignment to the end (1.0).
start → const AxisAlignmentDirectional
Alignment to the start (-1.0).