ButtonGroupData.vertical constructor

const ButtonGroupData.vertical({
  1. double top = 1.0,
  2. double bottom = 1.0,
})

Creates vertical group data with top and bottom multipliers.

Both start and end on each side use the same value.

Implementation

const ButtonGroupData.vertical({
  double top = 1.0,
  double bottom = 1.0,
})  : topStartValue = top,
      topEndValue = top,
      bottomStartValue = bottom,
      bottomEndValue = bottom;