ButtonGroupItem constructor
Creates a ButtonGroupItem widget with the specified child.
Parameters:
child(Widget, required): The widget to display within the button group item.
Implementation
const ButtonGroupItem({super.key, required this.child});
Creates a ButtonGroupItem widget with the specified child.
Parameters:
child (Widget, required): The widget to display within the button group item.const ButtonGroupItem({super.key, required this.child});