ButtonStyle.menu constructor
const
ButtonStyle.menu({
Creates a menu button style for dropdown menu triggers.
Menu buttons are designed for triggering dropdown menus, with appropriate spacing and styling for menu contexts.
Implementation
const ButtonStyle.menu({
this.size = ButtonSize.normal,
this.density = ButtonDensity.normal,
this.shape = ButtonShape.rectangle,
}) : variance = ButtonVariance.menu;