ButtonStyle.primary constructor

const ButtonStyle.primary({
  1. ButtonSize size = ButtonSize.normal,
  2. ButtonDensity density = ButtonDensity.normal,
  3. ButtonShape shape = ButtonShape.rectangle,
})

Creates a primary button style with prominent filled appearance.

Primary buttons use the theme's primary color with high contrast, making them ideal for the main action on a screen.

Implementation

const ButtonStyle.primary({
  this.size = ButtonSize.normal,
  this.density = ButtonDensity.normal,
  this.shape = ButtonShape.rectangle,
}) : variance = ButtonVariance.primary;