ButtonStyle.text constructor

const ButtonStyle.text({
  1. ButtonSize size = ButtonSize.normal,
  2. ButtonDensity density = ButtonDensity.normal,
  3. ButtonShape shape = ButtonShape.rectangle,
})

Creates a text-only button style with no background or border.

Text buttons display only their text content, making them the most minimal button style for unobtrusive actions.

Implementation

const ButtonStyle.text({
  this.size = ButtonSize.normal,
  this.density = ButtonDensity.normal,
  this.shape = ButtonShape.rectangle,
}) : variance = ButtonVariance.text;