ButtonStyleOverride.inherit constructor

Creates a button style override in inherit mode.

Overrides chain with parent overrides, allowing nested customization where each level can modify the result of the previous level.

Implementation

const ButtonStyleOverride.inherit({
  super.key,
  this.decoration,
  this.mouseCursor,
  this.padding,
  this.textStyle,
  this.iconTheme,
  this.margin,
  required this.child,
}) : inherit = true;