mouseCursor property
Returns the mouse cursor appearance based on button state.
Implementation
@override
final ButtonStateProperty<MouseCursor> mouseCursor;
Returns the mouse cursor appearance based on button state.
@override
final ButtonStateProperty<MouseCursor> mouseCursor;