builder property
Builder function that creates the widget from the value.
Implementation
final Widget Function(BuildContext context, T value) builder;
Builder function that creates the widget from the value.
final Widget Function(BuildContext context, T value) builder;