items property
The list of calendar grid items including current and adjacent month dates.
Implementation
final List<CalendarGridItem> items;
The list of calendar grid items including current and adjacent month dates.
final List<CalendarGridItem> items;