borderRadius property
Border radius for rounded corners on the card.
If null, uses default border radius from the theme.
Implementation
final BorderRadiusGeometry? borderRadius;
Border radius for rounded corners on the card.
If null, uses default border radius from the theme.
final BorderRadiusGeometry? borderRadius;