filled property
Whether the card has a filled background.
When true, the card has a solid background color. When false or
null, uses theme defaults.
Implementation
final bool? filled;
Whether the card has a filled background.
When true, the card has a solid background color. When false or
null, uses theme defaults.
final bool? filled;