strokeWidth property
The width of the progress stroke line.
Type: double?. If null, calculates proportionally as size/12.
Controls the thickness of both progress and background arcs.
Implementation
final double? strokeWidth;
The width of the progress stroke line.
Type: double?. If null, calculates proportionally as size/12.
Controls the thickness of both progress and background arcs.
final double? strokeWidth;