value property
The progress completion value between 0.0 and 1.0.
Type: double?. If null, displays indeterminate spinning animation.
When provided, shows progress as a filled arc from 0% to value*100%.
Implementation
final double? value;
The progress completion value between 0.0 and 1.0.
Type: double?. If null, displays indeterminate spinning animation.
When provided, shows progress as a filled arc from 0% to value*100%.
final double? value;