CodepointPredicate typedef

CodepointPredicate = bool Function(int codepoint)

A predicate that tests whether a Unicode codepoint is valid.

Parameters:

  • codepoint (int): The Unicode codepoint to test.

Returns: true if the codepoint passes the predicate, false otherwise.

Implementation

typedef CodepointPredicate = bool Function(int codepoint);