ColorPickerMode enum
Defines the color representation mode for color pickers.
Specifies which color model and input controls to display in the color picker interface. Each mode provides different controls optimized for that color space.
Values
- rgb → const ColorPickerMode
-
RGB (Red, Green, Blue) color mode.
- hsl → const ColorPickerMode
-
HSL (Hue, Saturation, Lightness) color mode.
- hsv → const ColorPickerMode
-
HSV (Hue, Saturation, Value) color mode.
- hex → const ColorPickerMode
-
Hexadecimal color code mode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ColorPickerMode> - A constant List of the values in this enum, in order of their declaration.