Colors class

A collection of color constants and shades for shadcn_flutter.

This class provides predefined colors and color shades that can be used throughout the application. All colors follow the shadcn design system.

Constructors

Colors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

primaries List<Color>
List of primary color swatches from the Material color palette.
final

Constants

amber → const ColorShades
Amber color shades (50-950).
black → const Color
Pure black color.
blue → const ColorShades
Blue color shades (50-950).
cyan → const ColorShades
Cyan color shades (50-950).
emerald → const ColorShades
Emerald color shades (50-950).
fuchsia → const ColorShades
Fuchsia color shades (50-950).
gray → const ColorShades
Gray color shades (50-950).
green → const ColorShades
Green color shades (50-950).
indigo → const ColorShades
Indigo color shades (50-950).
lime → const ColorShades
Lime color shades (50-950).
neutral → const ColorShades
Neutral color shades (50-950).
orange → const ColorShades
Orange color shades (50-950).
pink → const ColorShades
Pink color shades (50-950).
purple → const ColorShades
Purple color shades (50-950).
red → const ColorShades
Red color shades (50-950).
rose → const ColorShades
Rose color shades (50-950).
sky → const ColorShades
Sky color shades (50-950).
slate → const ColorShades
Slate color shades (50-950).
stone → const ColorShades
Stone color shades (50-950).
teal → const ColorShades
Teal color shades (50-950).
transparent → const Color
Fully transparent color.
violet → const ColorShades
Violet color shades (50-950).
white → const Color
Pure white color.
yellow → const ColorShades
Yellow color shades (50-950).
zinc → const ColorShades
Zinc color shades (50-950).