find method

T? find(
  1. BuildContext context
)

Looks up the button theme of type T from the component theme.

Returns the theme instance if found in the widget tree, or null if not present.

Implementation

T? find(BuildContext context) {
  return ComponentTheme.maybeOf<T>(context);
}