size property
Override size of the checkbox square in logical pixels.
When null, uses the theme size or framework default (16px scaled).
Implementation
final double? size;
Override size of the checkbox square in logical pixels.
When null, uses the theme size or framework default (16px scaled).
final double? size;