decreaseStep property
The step size for keyboard decrement actions.
When the user presses the decrease key, the slider value will decrease by
this amount. If null, a default decrement is used.
Implementation
final double? decreaseStep;
The step size for keyboard decrement actions.
When the user presses the decrease key, the slider value will decrease by
this amount. If null, a default decrement is used.
final double? decreaseStep;