increaseStep property
The step size for keyboard increment actions.
When the user presses the increase key, the slider value will increase by
this amount. If null, a default increment is used.
Implementation
final double? increaseStep;
The step size for keyboard increment actions.
When the user presses the increase key, the slider value will increase by
this amount. If null, a default increment is used.
final double? increaseStep;