borderRadius property
Border radius for the switch track.
If null, uses the default border radius from the theme.
Implementation
final BorderRadiusGeometry? borderRadius;
Border radius for the switch track.
If null, uses the default border radius from the theme.
final BorderRadiusGeometry? borderRadius;