Convert<F, T> typedef
Convert<F, T> =
T Function(F value)
Function type for converting from type F to type T.
Implementation
typedef Convert<F, T> = T Function(F value);
Function type for converting from type F to type T.
typedef Convert<F, T> = T Function(F value);