toSearchString method
Returns a string that can be used to search for this country
Implementation
String toSearchString() {
return '$name $code $dialCode $flag';
}
Returns a string that can be used to search for this country
String toSearchString() {
return '$name $code $dialCode $flag';
}