DashedContainerProperties class

Properties for defining a dashed container border appearance.

Encapsulates the visual properties of a dashed container border including dash width, gap, thickness, color, and border radius. Supports interpolation.

Constructors

DashedContainerProperties({required double width, required double gap, required double thickness, required Color color, required BorderRadiusGeometry borderRadius})
Creates DashedContainerProperties.
const

Properties

borderRadius BorderRadiusGeometry
Border radius for rounded corners.
final
color Color
Color of the dashed border.
final
gap double
Gap between consecutive dash segments.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
Thickness of the border.
final
width double
Width of each dash segment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited