DashedLineProperties class

Properties for defining a dashed line appearance.

Encapsulates the visual properties of a dashed line including dash width, gap between dashes, thickness, and color. Supports interpolation for animations.

Constructors

DashedLineProperties({required double width, required double gap, required double thickness, required Color color})
Creates DashedLineProperties.
const

Properties

color Color
Color of the dashed line.
final
gap double
Gap between consecutive dash segments.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
Thickness (height) of the line.
final
width double
Width of each dash segment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(DashedLineProperties a, DashedLineProperties b, double t) DashedLineProperties
Linearly interpolates between two DashedLineProperties.