data property
T
get
data
The data that will be provided to the descendants.
Implementation
T get data {
assert(_data != null, 'No Data<$T> found in context');
return _data!;
}
The data that will be provided to the descendants.
T get data {
assert(_data != null, 'No Data<$T> found in context');
return _data!;
}