computeValueRange property

(int?, int?) Function(Map<DatePart, int> values) computeValueRange
final

Function that computes the valid value range for this component.

Takes a map of already-set date component values and returns the minimum and maximum valid values for this component, considering constraints like month lengths or leap years.

Implementation

final (int? min, int? max) Function(Map<DatePart, int> values)
    computeValueRange;