chipSerializer property
Converts a chip value into its clipboard string representation.
Falls back to Object.toString when null.
Implementation
final String Function(T value)? chipSerializer;
Converts a chip value into its clipboard string representation.
Falls back to Object.toString when null.
final String Function(T value)? chipSerializer;