computeValueRange property
Function that computes the valid value range for this component.
Implementation
final (int? min, int? max) Function(Map<DurationPart, int> values)
computeValueRange;
Function that computes the valid value range for this component.
final (int? min, int? max) Function(Map<DurationPart, int> values)
computeValueRange;