DynamicFormKey class

Inheritance

Constructors

DynamicFormKey(Object key)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Object
The underlying key object.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
Gets the generic type parameter of this key.
no setterinherited

Methods

getValue(FormMapValues values) Object?
Gets the value associated with this key from the form values map.
inherited
isInstanceOf(dynamic value) bool
Checks if a dynamic value is an instance of this key's type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](FormMapValues values) Object?
Operator overload to get the value from form values (same as getValue).
inherited