EyeDropperLayerScope class abstract

Provides access to eye dropper functionality in the widget tree.

EyeDropperLayerScope is an abstract interface that allows widgets to request color picking functionality from an ancestor EyeDropperLayer. Use the static methods to find the scope in the widget tree.

Constructors

EyeDropperLayerScope()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promptPickColor([ColorHistoryStorage? historyStorage]) Future<Color?>
Prompts the user to pick a color from the screen.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

find(BuildContext context) EyeDropperLayerScope
Finds the nearest EyeDropperLayerScope in the widget tree.
findRoot(BuildContext context) EyeDropperLayerScope
Finds the root EyeDropperLayerScope in the widget tree.