mounted property
bool
get
mounted
Whether the widget is currently mounted in the widget tree.
Implementation
bool get mounted;
Whether the widget is currently mounted in the widget tree.
bool get mounted;