getValue method
Gets the value associated with this key from the form values map.
Implementation
T? getValue(FormMapValues values) {
return values.getValue(this);
}
Gets the value associated with this key from the form values map.
T? getValue(FormMapValues values) {
return values.getValue(this);
}