isInstanceOf method
Checks if a dynamic value is an instance of this key's type.
Implementation
bool isInstanceOf(dynamic value) {
return value is T;
}
Checks if a dynamic value is an instance of this key's type.
bool isInstanceOf(dynamic value) {
return value is T;
}