operator [] method
Operator overload to get the value from form values (same as getValue).
Implementation
T? operator [](FormMapValues values) {
return values.getValue(this);
}
Operator overload to get the value from form values (same as getValue).
T? operator [](FormMapValues values) {
return values.getValue(this);
}