trailing property
Widget displayed at the end of the input.
Can be used for action buttons, status indicators, or additional context related to the input content.
Implementation
final Widget? trailing;
Widget displayed at the end of the input.
Can be used for action buttons, status indicators, or additional context related to the input content.
final Widget? trailing;