IndentGuidePath class

Branch line implementation with connected path lines.

Displays L-shaped or T-shaped connectors showing the hierarchical structure of the tree. This is the most common branch line style.

Example:

Tree(
  branchLine: BranchLine.path,
  // or with custom color:
  branchLine: IndentGuidePath(color: Colors.grey),
);
Implemented types

Constructors

IndentGuidePath({Color? color})
Creates an IndentGuidePath with optional custom color.
const

Properties

color Color?
Custom color for the path. If null, uses the theme border color.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, List<TreeNodeDepth> depth, int index) Widget
Builds the visual representation of branch lines for a tree node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited