InputAboveBelowFeature class

Adds a custom widget above or below the text input area.

Use this feature to place helper content inside the input decoration, directly above or below the editable text.

Example:

TextField(
  features: [
    InputAboveBelowFeature(
      child: Text('Billing email').small().muted(),
      position: InputFeaturePosition.above,
    ),
  ],
)
Inheritance

Constructors

InputAboveBelowFeature({InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true, Widget? child, InputFeaturePosition position = InputFeaturePosition.below})
Creates an InputAboveBelowFeature.
const
InputAboveBelowFeature.above(Widget? child, {InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true})
Creates an InputAboveBelowFeature displayed above the input text.
const
InputAboveBelowFeature.below(Widget? child, {InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true})
Creates an InputAboveBelowFeature displayed below the input text.
const

Properties

child Widget?
Widget shown above or below the editable text.
final
hashCode int
The hash code for this object.
no setterinherited
position InputFeaturePosition
Position of the child relative to the editable text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipFocusTraversal bool
Whether to skip this feature in focus traversal.
finalinherited
visibility InputFeatureVisibility
Visibility mode for this input feature.
finalinherited

Methods

createState() InputFeatureState<InputFeature>
Creates the state for this input feature.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited