canUpdate static method
Checks if an old feature can be updated to a new feature.
Implementation
static bool canUpdate(InputFeature oldFeature, InputFeature newFeature) {
return oldFeature.runtimeType == newFeature.runtimeType;
}
Checks if an old feature can be updated to a new feature.
static bool canUpdate(InputFeature oldFeature, InputFeature newFeature) {
return oldFeature.runtimeType == newFeature.runtimeType;
}