attached property
bool
get
attached
Whether this feature is currently attached to a text field.
Implementation
bool get attached => _attached != null;
Whether this feature is currently attached to a text field.
bool get attached => _attached != null;