buildAbove method

Iterable<Widget> buildAbove()

Builds widgets displayed above the input, inside the decoration.

Override to provide widgets rendered above the editable text.

Implementation

Iterable<Widget> buildAbove() sync* {}