buildBelow method

Iterable<Widget> buildBelow()

Builds widgets displayed below the input, inside the decoration.

Override to provide widgets rendered below the editable text.

Implementation

Iterable<Widget> buildBelow() sync* {}