canShow abstract method
Checks if the feature can be shown in the current state.
Returns true if all visibility conditions are met.
Implementation
bool canShow(TextFieldState state);
Checks if the feature can be shown in the current state.
Returns true if all visibility conditions are met.
bool canShow(TextFieldState state);