value property

  1. @override
String? get value
override

The current value of this part, or null if it doesn't hold a value.

Implementation

@override

/// The current value of this part, or null if it doesn't hold a value.
String? get value => null;