withValue method

  1. @override
FormattedValuePart withValue(
  1. String value
)
override

Creates a copy of this part with the specified value.

Implementation

@override

/// Creates a copy of this part with the specified value.
FormattedValuePart withValue(String value) {
  return FormattedValuePart(this, value);
}