InputTrailingFeature class

Adds a custom widget to the trailing (right) side of the input field.

Allows you to place any widget after the input text, such as icons, buttons, or other decorative elements.

Example:

TextField(
  features: [
    InputTrailingFeature(
      Icon(Icons.arrow_forward),
    ),
  ],
)
Inheritance

Constructors

InputTrailingFeature(Widget suffix, {InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true})
Creates an InputTrailingFeature.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipFocusTraversal bool
Whether to skip this feature in focus traversal.
finalinherited
suffix Widget
The widget to display on the trailing side.
final
visibility InputFeatureVisibility
Visibility mode for this input feature.
finalinherited

Methods

createState() InputFeatureState<InputFeature>
Creates the state for this input feature.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited