tooltipAnchorAlignment property
Alignment point on the child widget where tooltip anchors.
Implementation
final AlignmentGeometry? tooltipAnchorAlignment;
Alignment point on the child widget where tooltip anchors.
final AlignmentGeometry? tooltipAnchorAlignment;