KeyboardShortcutDisplayHandle class

Handle for accessing keyboard shortcut display builders.

Wraps a keyboard shortcut display builder function to provide a consistent API for building key displays.

Constructors

KeyboardShortcutDisplayHandle(KeyboardShortcutDisplayBuilder _builder)
Creates a handle with the specified builder.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildKeyboardDisplay(BuildContext context, LogicalKeyboardKey key) Widget
Builds a display widget for the specified keyboard key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited