tabKey property
The unique key identifying this tab.
Used instead of positional index for tab selection and tracking.
Implementation
@override
T get tabKey => key.value;
The unique key identifying this tab.
Used instead of positional index for tab selection and tracking.
@override
T get tabKey => key.value;