LinearProgressIndicatorTheme constructor

const LinearProgressIndicatorTheme({
  1. Color? color,
  2. Gradient? progressGradient,
  3. Color? backgroundColor,
  4. double? minHeight,
  5. BorderRadiusGeometry? borderRadius,
  6. bool? showSparks,
  7. bool? disableAnimation,
})

Creates a LinearProgressIndicatorTheme.

All parameters are optional and can be null to use intelligent defaults based on the current theme configuration and design system values.

Example:

const LinearProgressIndicatorTheme(
  color: Colors.blue,
  backgroundColor: Colors.grey,
  minHeight: 4.0,
  borderRadius: BorderRadius.circular(2.0),
  showSparks: true,
);

Implementation

const LinearProgressIndicatorTheme({
  this.color,
  this.progressGradient,
  this.backgroundColor,
  this.minHeight,
  this.borderRadius,
  this.showSparks,
  this.disableAnimation,
});