ListInsertChange<T> class
A list change that inserts an item.
Inserts item at the specified index in the list.
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
index
→ int
-
The index where the item will be inserted.
final
-
item
→ T
-
The item to insert.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(List<T> list)
→ void
-
Applies this change to the given
list.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited