remove method
Removes the first occurrence of value from this list.
Returns true if value was in the list, false otherwise.
The list must be growable.
final parts = <String>['head', 'shoulders', 'knees', 'toes'];
final retVal = parts.remove('head'); // true
print(parts); // [shoulders, knees, toes]
The method has no effect if value was not in the list.
final parts = <String>['shoulders', 'knees', 'toes'];
// Note: 'head' has already been removed.
final retVal = parts.remove('head'); // false
print(parts); // [shoulders, knees, toes]
Implementation
@override
bool remove(Object? value) {
final int index = _list.indexOf(value as T);
if (index == -1) {
return false;
}
_list.removeAt(index);
notifyListeners(ListChangeDetails<T>(const [], [value], index));
return true;
}