value property
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
Implementation
@override
Map<K, V> get value => UnmodifiableMapView<K, V>(_map);
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
@override
Map<K, V> get value => UnmodifiableMapView<K, V>(_map);