value property
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
Implementation
@override
R get value => _mapper(_notifier.value);
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
@override
R get value => _mapper(_notifier.value);