padding property
Internal padding around the menu items.
Defines the space between the popup's border and its content.
If null, uses theme default or adaptive default based on overlay type.
Implementation
final EdgeInsetsGeometry? padding;
Internal padding around the menu items.
Defines the space between the popup's border and its content.
If null, uses theme default or adaptive default based on overlay type.
final EdgeInsetsGeometry? padding;