surfaceBlur property
Amount of blur to apply to the surface behind the popup.
Higher values create more blur effect. If null, uses theme default.
Implementation
final double? surfaceBlur;
Amount of blur to apply to the surface behind the popup.
Higher values create more blur effect. If null, uses theme default.
final double? surfaceBlur;