find<T> static method

T find<T>(
  1. BuildContext context,
  2. Symbol key
)

Find the data of the given type from the context. Throws an assertion error if the data is not found.

  • T The type of the data.
  • context The build context.
  • key The data key.

Implementation

static T find<T>(BuildContext context, Symbol key) {
  return MultiModel.find(context, key);
}