ofProperty<T> static method

ModelProperty<T> ofProperty<T>(
  1. BuildContext context,
  2. Symbol key
)

Find and listen to property changes of the data with the given type from the context. Throws an assertion error if the data is not found.

  • T The type of the data.
  • context The build context.
  • key The data key.

Implementation

static ModelProperty<T> ofProperty<T>(BuildContext context, Symbol key) {
  return MultiModel.ofProperty(context, key);
}