change method

void change(
  1. BuildContext context,
  2. T data
)

Change the data of the model with the given key. Throws an assertion error if the model is read-only.

  • T The type of the data.
  • context The build context.
  • key The data key.
  • data The new data.

Implementation

void change(BuildContext context, T data) {
  MultiModel.change(context, key, data);
}