find method

T find(
  1. BuildContext context
)

Find the data of the given type from the context. Throws an assertion error if the data is not found.

  • T The type of the data.
  • context The build context.
  • key The data key.

Implementation

T find(BuildContext context) {
  return MultiModel.find<T>(context, key);
}