maybeOf method

T? maybeOf(
  1. BuildContext context
)

Optionally find and listen to data changes of the data with the given type from the context.

  • T The type of the data.
  • context The build context.
  • key The data key.

Implementation

T? maybeOf(BuildContext context) {
  return MultiModel.maybeOf<T>(context, key);
}