of method
Find and listen to data changes of the data with the given type from the context.
TThe type of the data.contextThe build context.- key The data key.
Implementation
T of(BuildContext context) {
return MultiModel.of<T>(context, key);
}
Find and listen to data changes of the data with the given type from the context.
T The type of the data.context The build context.T of(BuildContext context) {
return MultiModel.of<T>(context, key);
}