MultiCalendarValue class

Calendar value representing multiple selected dates.

Encapsulates a list of individually selected dates. Provides lookup functionality to determine if a date is among the selected dates. Used with CalendarSelectionMode.multi.

Inheritance

Constructors

MultiCalendarValue(List<DateTime> dates)
Creates a multi calendar value with the specified list of dates.

Properties

dates List<DateTime>
The list of selected dates.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view CalendarView
Returns the calendar view associated with this value.
no setteroverride

Methods

lookup(int year, [int? month, int? day]) CalendarValueLookup
Looks up whether the specified date is part of this calendar value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMulti() MultiCalendarValue
Converts this value to a multi calendar value.
override
toRange() RangeCalendarValue
Converts this value to a range calendar value.
override
toSingle() SingleCalendarValue
Converts this value to a single calendar value.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override