NavigationLabelPosition enum

Position of navigation item labels relative to icons.

Inheritance
Available extensions

Values

start → const NavigationLabelPosition

Label before icon (left in LTR, right in RTL)

end → const NavigationLabelPosition

Label after icon (right in LTR, left in RTL)

top → const NavigationLabelPosition

Label above icon

bottom → const NavigationLabelPosition

Label below icon

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NavigationLabelPosition>
A constant List of the values in this enum, in order of their declaration.