spacing property
Spacing between items within the same row.
Controls horizontal spacing between grid items. If not specified, uses a default value based on the theme's scaling factor.
Implementation
final double? spacing;
Spacing between items within the same row.
Controls horizontal spacing between grid items. If not specified, uses a default value based on the theme's scaling factor.
final double? spacing;