isActive method
Checks if the given menu item is currently active.
Parameters:
item(NavigationMenuItemState, required): the menu item to check
Returns: bool — true if the item is active and popover is open
Implementation
bool isActive(NavigationMenuItemState item) {
return _overlayController.hasOpenOverlay &&
widget.children[_activeIndex.value] == item.widget;
}