keepCrossAxisSize property
Whether to maintain intrinsic size along the cross axis.
Controls width sizing behavior when the sidebar's width constraints are unconstrained.
Implementation
final bool keepCrossAxisSize;
Whether to maintain intrinsic size along the cross axis.
Controls width sizing behavior when the sidebar's width constraints are unconstrained.
final bool keepCrossAxisSize;