keepMainAxisSize property
Whether to maintain intrinsic size along the main axis.
Controls height sizing behavior when the sidebar's height constraints are unconstrained.
Implementation
final bool keepMainAxisSize;
Whether to maintain intrinsic size along the main axis.
Controls height sizing behavior when the sidebar's height constraints are unconstrained.
final bool keepMainAxisSize;