onSelected property
Callback invoked when a navigation item is selected.
Called with the key of the selected item. Use this to update the selection state and handle navigation actions.
Implementation
final ValueChanged<Key?>? onSelected;
Callback invoked when a navigation item is selected.
Called with the key of the selected item. Use this to update the selection state and handle navigation actions.
final ValueChanged<Key?>? onSelected;