immediateValueChange property

bool? immediateValueChange
final

Whether to inform value change callback immediately upon user interaction with the editor. If null, defaults to true for popover mode and false for dialog mode.

Implementation

final bool? immediateValueChange;