ObjectInputSaveButton typedef
ObjectInputSaveButton = PrimaryButton
Type definition for the save button in an object input form field.
Implementation
typedef ObjectInputSaveButton = PrimaryButton;
Type definition for the save button in an object input form field.
typedef ObjectInputSaveButton = PrimaryButton;