OverlayPosition enum

Position for overlay components like drawers and sheets.

Inheritance
Available extensions

Values

left → const OverlayPosition

Positioned on the left edge

Positioned on the right edge

top → const OverlayPosition

Positioned on the top edge

bottom → const OverlayPosition

Positioned on the bottom edge

start → const OverlayPosition

Positioned at the start (left in LTR, right in RTL)

end → const OverlayPosition

Positioned at the end (right in LTR, left in RTL)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OverlayPosition>
A constant List of the values in this enum, in order of their declaration.