PanelSibling enum

Represents the position of a panel relative to another panel.

Used to specify which neighboring panel should be affected when expanding or collapsing a resizable panel.

Inheritance
Available extensions

Values

before → const PanelSibling

The panel before (left/top) the current panel.

const PanelSibling(-1)
after → const PanelSibling

The panel after (right/bottom) the current panel.

const PanelSibling(1)
both → const PanelSibling

Both panels on either side of the current panel.

const PanelSibling(0)

Properties

direction int
Direction value used internally for calculations.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PanelSibling>
A constant List of the values in this enum, in order of their declaration.