PhoneInputKey typedef
Form key type for phone input fields with PhoneNumber values.
Implementation
typedef PhoneInputKey = FormKey<PhoneNumber>;
Form key type for phone input fields with PhoneNumber values.
typedef PhoneInputKey = FormKey<PhoneNumber>;