RadioGroupData<T> class

Data class holding radio group state information.

Contains the selected item and enabled state for a radio group.

Constructors

RadioGroupData(T? selectedItem, bool enabled)
Creates radio group data.

Properties

enabled bool
Whether the radio group is enabled.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItem → T?
The currently selected item value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override