RangeCalendarValue class

Calendar value representing a date range selection.

Encapsulates a date range with start and end dates. Provides lookup functionality to determine if a date is the start, end, within the range, or outside. Used with CalendarSelectionMode.range.

The range is automatically normalized so start is always before or equal to end.

Inheritance

Constructors

RangeCalendarValue(DateTime start, DateTime end)
Creates a range calendar value with the specified start and end dates.

Properties

end DateTime
The end date of the range (always >= start).
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The start date of the range (always <= end).
final
view CalendarView
Returns the calendar view associated with this value.
no setteroverride

Methods

lookup(int year, [int? month, int? day]) CalendarValueLookup
Looks up whether the specified date is part of this calendar value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMulti() MultiCalendarValue
Converts this value to a multi calendar value.
override
toRange() RangeCalendarValue
Converts this value to a range calendar value.
override
toSingle() SingleCalendarValue
Converts this value to a single calendar value.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override