completeDuration property
Duration for the completion animation.
Time to display the completion state before hiding the indicator.
Implementation
final Duration? completeDuration;
Duration for the completion animation.
Time to display the completion state before hiding the indicator.
final Duration? completeDuration;