target property
T
target
final
The target value to animate to from the previous keyframe's end.
Implementation
final T target;
The target value to animate to from the previous keyframe's end.
final T target;