horizontalController property
Optional controller for horizontal scrolling owned by this ResizableTable. See Table.horizontalController.
Implementation
final ScrollController? horizontalController;
Optional controller for horizontal scrolling owned by this ResizableTable. See Table.horizontalController.
final ScrollController? horizontalController;