ScaffoldPaddingStorage class

Storage for scaffold padding values.

Holds padding values for all four sides of the scaffold content area.

Constructors

ScaffoldPaddingStorage({required double top, required double left, required double right, required double bottom})
Creates a ScaffoldPaddingStorage.

Properties

bottom double
Bottom padding value.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
left double
Left padding value.
getter/setter pair
Right padding value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
Top padding value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited