cornerRadius property
The corner radius the root backdrop clips to when fully open. When null,
Theme.of(context).radiusXxl is used.
Implementation
final double? cornerRadius;
The corner radius the root backdrop clips to when fully open. When null,
Theme.of(context).radiusXxl is used.
final double? cornerRadius;