minScale property
The scale applied to the backdrop when fully open. Defaults to kBackdropScaleDown (0.95).
Implementation
final double minScale;
The scale applied to the backdrop when fully open. Defaults to kBackdropScaleDown (0.95).
final double minScale;