child property

Widget child
final

The child widget containing sortable items within a scrollable area.

Type: Widget. Typically a scrollable widget like ListView or GridView that contains sortable items and uses the same controller.

Implementation

final Widget child;