controller property

ScrollController controller
final

The scroll controller that manages the scrollable area.

Type: ScrollController. Must be the same controller used by the scrollable widget in the child tree. This allows the layer to control scrolling during drag operations.

Implementation

final ScrollController controller;