style property
The text style to apply to the text.
If null, uses the default text style from the theme.
Implementation
final TextStyle? style;
The text style to apply to the text.
If null, uses the default text style from the theme.
final TextStyle? style;