SelectableTextTheme class

Theme data for SelectableText to customize cursor and selection behavior.

Inheritance

Constructors

SelectableTextTheme({double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, bool? enableInteractiveSelection})
Theme data for SelectableText to customize cursor and selection behavior.
const

Properties

cursorColor Color?
Color of the text cursor.
final
cursorHeight double?
Height of the text cursor in logical pixels.
final
cursorRadius Radius?
Corner radius of the text cursor.
final
cursorWidth double?
Width of the text cursor in logical pixels.
final
enableInteractiveSelection bool?
Whether to enable interactive text selection (e.g., selecting with mouse/touch).
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionHeightStyle BoxHeightStyle?
How tall the selection highlight boxes should be.
final
selectionWidthStyle BoxWidthStyle?
How wide the selection highlight boxes should be.
final

Methods

copyWith({ValueGetter<double?>? cursorWidth, ValueGetter<double?>? cursorHeight, ValueGetter<Radius?>? cursorRadius, ValueGetter<Color?>? cursorColor, ValueGetter<BoxHeightStyle?>? selectionHeightStyle, ValueGetter<BoxWidthStyle?>? selectionWidthStyle, ValueGetter<bool?>? enableInteractiveSelection}) SelectableTextTheme
Creates a copy of this theme with optionally replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override