cursorHeight property
Height of the text cursor in logical pixels.
If null, the cursor height matches the line height of the text.
Implementation
final double? cursorHeight;
Height of the text cursor in logical pixels.
If null, the cursor height matches the line height of the text.
final double? cursorHeight;