cursorWidth property
Width of the text cursor in logical pixels.
If null, uses the default cursor width from the platform or theme.
Implementation
final double? cursorWidth;
Width of the text cursor in logical pixels.
If null, uses the default cursor width from the platform or theme.
final double? cursorWidth;