offset property
double
get
offset
The current visible extent of the sheet, in logical pixels.
Implementation
double get offset => _state?.currentOffset ?? 0.0;
The current visible extent of the sheet, in logical pixels.
double get offset => _state?.currentOffset ?? 0.0;