SingleChartColorScheme class

A chart color scheme that uses a single color for all chart elements.

Implemented types

Constructors

SingleChartColorScheme(Color color)
Creates a single color chart scheme.
const

Properties

chart1 Color
Color for the first chart series.
no setteroverride
chart2 Color
Color for the second chart series.
no setteroverride
chart3 Color
Color for the third chart series.
no setteroverride
chart4 Color
Color for the fourth chart series.
no setteroverride
chart5 Color
Color for the fifth chart series.
no setteroverride
chartColors List<Color>
The list of chart colors.
no setteroverride
color Color
The single color used for all chart elements.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited