enabled property

bool? enabled
final

Whether the slider is interactive.

When false or null with no onChanged callback, the slider is displayed in a disabled state and does not respond to user input.

Implementation

final bool? enabled;