value property
The current value of the slider.
Can be either a single value or a range. The slider's visual state reflects this value.
Implementation
final SliderValue value;
The current value of the slider.
Can be either a single value or a range. The slider's visual state reflects this value.
final SliderValue value;