canAcceptBottom property

Predicate<SortableData<T>>? canAcceptBottom
final

Predicate to determine if data can be accepted when dropped below this widget.

Type: Predicate<SortableData<T>>?. If null, drops from the bottom are not accepted. Called before onAcceptBottom to validate the drop operation.

Implementation

final Predicate<SortableData<T>>? canAcceptBottom;