canAcceptLeft property

Predicate<SortableData<T>>? canAcceptLeft
final

Predicate to determine if data can be accepted when dropped to the left of this widget.

Type: Predicate<SortableData<T>>?. If null, drops from the left are not accepted. Called before onAcceptLeft to validate the drop operation.

Implementation

final Predicate<SortableData<T>>? canAcceptLeft;