canAcceptRight property

Predicate<SortableData<T>>? canAcceptRight
final

Predicate to determine if data can be accepted when dropped to the right of this widget.

Type: Predicate<SortableData<T>>?. If null, drops from the right are not accepted. Called before onAcceptRight to validate the drop operation.

Implementation

final Predicate<SortableData<T>>? canAcceptRight;