candidateFallback property

Widget? candidateFallback
final

Widget displayed when the item is a candidate for dropping.

Type: Widget?. Shows alternative styling when the dragged item hovers over this sortable as a potential drop target.

Implementation

final Widget? candidateFallback;