child property

Widget child
final

The child widget that defines the drop zone area.

Type: Widget. This widget's bounds determine the area where drops can be detected. The child is rendered normally with an invisible overlay for drop detection.

Implementation

final Widget child;