child property
The child widget tree containing sortable widgets.
Type: Widget. All sortable widgets must be descendants of this child
tree to function properly with the layer.
Implementation
final Widget child;
The child widget tree containing sortable widgets.
Type: Widget. All sortable widgets must be descendants of this child
tree to function properly with the layer.
final Widget child;