dropCurve property
Animation curve for drop transitions.
Type: Curve?. If null, uses Curves.easeInOut. Controls the easing
behavior of items animating to their final drop position.
Implementation
final Curve? dropCurve;
Animation curve for drop transitions.
Type: Curve?. If null, uses Curves.easeInOut. Controls the easing
behavior of items animating to their final drop position.
final Curve? dropCurve;