StackParentData class

Parent data for use with RenderStack.

Inheritance
Mixed-in types

Constructors

StackParentData()

Properties

bottom double?
The distance by which the child's bottom edge is inset from the bottom of the stack.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
The child's height.
getter/setter pairinherited
isPositioned bool
Whether this child is considered positioned.
no setterinherited
left double?
The distance by which the child's left edge is inset from the left of the stack.
getter/setter pairinherited
nextSibling RenderBox?
The next sibling in the parent's child list.
getter/setter pairinherited
nextSortedSibling RenderBox?
Next sibling in the sorted paint order linked list.
getter/setter pairinherited
offset Offset
The offset at which to paint the child in the parent's coordinate system.
getter/setter pairinherited
paintIndex int
Internal index used for sorting.
getter/setter pairinherited
paintOrder int?
The paint order of this child. Higher values are painted on top. If null, uses the default order (0).
getter/setter pairinherited
previousSibling RenderBox?
The previous sibling in the parent's child list.
getter/setter pairinherited
previousSortedSibling RenderBox?
Previous sibling in the sorted paint order linked list.
getter/setter pairinherited
rect RelativeRect
Get or set the current values in terms of a RelativeRect object.
getter/setter pairinherited
The distance by which the child's right edge is inset from the right of the stack.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double?
The distance by which the child's top edge is inset from the top of the stack.
getter/setter pairinherited
width double?
The child's width.
getter/setter pairinherited

Methods

detach() → void
Clear the sibling pointers.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionedChildConstraints(Size stackSize) BoxConstraints
Computes the BoxConstraints the stack layout algorithm would give to this child, given the Size of the stack.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited