StillKeyframe<T> constructor

const StillKeyframe<T>(
  1. Duration duration, [
  2. T? value
])

Creates a still keyframe that holds a value.

Parameters

  • duration - How long to hold the value.
  • value - The value to hold, or null to use the previous keyframe's end value.

Notes

If value is null, this keyframe must not be the first in the timeline.

Implementation

const StillKeyframe(this.duration, [this.value]);