value property
T?
value
final
The value to hold, or null to use the previous keyframe's end value.
Implementation
final T? value;
The value to hold, or null to use the previous keyframe's end value.
final T? value;