enabled property
Whether this focusable element is enabled.
When false, the element cannot receive focus and is excluded from
the focus traversal order. Defaults to true.
Implementation
final bool enabled;
Whether this focusable element is enabled.
When false, the element cannot receive focus and is excluded from
the focus traversal order. Defaults to true.
final bool enabled;