borderWidth property
Width of the card's border in logical pixels.
If null, uses default border width from the theme.
Implementation
final double? borderWidth;
Width of the card's border in logical pixels.
If null, uses default border width from the theme.
final double? borderWidth;