SwitchController class

Controller for managing switch state.

Extends ValueNotifier with bool values to provide state management for switch widgets. Includes a convenience toggle method for flipping the switch state.

Example:

final controller = SwitchController(true);
controller.toggle(); // Now false
Inheritance
Mixed-in types

Constructors

SwitchController([bool value = false])
Creates a SwitchController.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void
Toggles the switch state between true and false.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited