horizontalController property
Optional controller for horizontal scrolling owned by this Table.
Same semantics as verticalController, for the horizontal axis.
Implementation
final ScrollController? horizontalController;
Optional controller for horizontal scrolling owned by this Table.
Same semantics as verticalController, for the horizontal axis.
final ScrollController? horizontalController;