verticalController property

ScrollController? verticalController
final

Optional controller for vertical scrolling owned by this Table.

When provided, the table wraps itself in a ScrollableClient and drives verticalOffset/viewportSize internally from this controller instead of requiring the caller to wire up their own ScrollableClient/Scrollable and pass verticalOffset manually. If both this and verticalOffset are provided, verticalOffset is ignored for the vertical axis.

Implementation

final ScrollController? verticalController;