TableRef class

Reference to a table row or column by index and span.

Used to identify specific rows or columns in table layouts, particularly for frozen/pinned row and column functionality.

Example:

TableRef(0, 2) // References rows/columns 0 and 1
TableRef(5)    // References row/column 5 with span of 1

Constructors

TableRef(int index, [int span = 1])
Creates a TableRef.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
Starting index of the reference.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span int
Number of rows/columns spanned. Defaults to 1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
test(int index, int span) bool
Tests if this reference includes the given index and span.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited