TableSize class abstract base

Base class for table sizing strategies.

Abstract class that defines how table columns and rows should be sized. Implementations include fixed, flexible, and intrinsic sizing modes.

Implementers

Constructors

TableSize()
Creates a TableSize.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited