time static method
Creates a formatter for time input with leading zeros.
Parameters:
length: The fixed length of the time string.
Implementation
static TextInputFormatter time({required int length}) {
return _TimeFormatter(length: length);
}
Creates a formatter for time input with leading zeros.
Parameters:
length: The fixed length of the time string.static TextInputFormatter time({required int length}) {
return _TimeFormatter(length: length);
}