transformWithController method

T transformWithController(
  1. AnimationController controller
)

Transforms the timeline using the controller's current value.

This is a convenience method that combines drive and Animatable.transform.

Parameters

  • controller - The animation controller to read the value from.

Returns

The current value of type T based on the controller's progress.

Example

final value = timeline.transformWithController(controller);

Implementation

T transformWithController(AnimationController controller) {
  return drive(controller).transform(controller.value);
}