WidgetInputOTPChild class

A widget-based OTP child that doesn't accept input.

Used for displaying static content like separators or spacers within an InputOTP widget. This child does not hold any value.

Example:

WidgetInputOTPChild(
  Icon(Icons.arrow_forward),
)
Inheritance

Constructors

WidgetInputOTPChild(Widget child)
Creates a WidgetInputOTPChild.
const

Properties

child Widget
The widget to display.
final
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
Whether this child can hold a value (i.e., is an input field).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, InputOTPChildData data) Widget
Builds the widget for this OTP child.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited