closed property

ValueNotifier<bool> closed
final

Notifier that indicates whether the window has been closed.

External code can listen to this notifier to react to window close events.

Implementation

final ValueNotifier<bool> closed = ValueNotifier(false);