attachedState property

WindowHandle get attachedState

The window handle this controller is attached to.

Provides access to the underlying window implementation for advanced operations. Only accessible when mounted is true.

Throws an assertion error if accessed when not mounted.

Implementation

WindowHandle get attachedState {
  assert(mounted, 'Window is not attached');
  return _attachedState!;
}