maximized property

Rect? get maximized

Maximized bounds, or null if the window is not maximized.

When non-null, indicates the window is in maximized state.

Implementation

Rect? get maximized => value.maximized;
set maximized (Rect? value)

Sets the maximized state and bounds.

Pass a Rect to maximize the window to those bounds. Pass null to restore the window from maximized state.

Implementation

set maximized(Rect? value) {
  if (value == maximized) return;
  this.value = this.value.withMaximized(value);
}