mounted property

bool get mounted

Whether the controller is currently attached to a window widget.

Returns true if the controller is mounted within a window widget and can safely access attachedState. Returns false otherwise.

Implementation

bool get mounted => _attachedState != null;