shouldMinifyWindow property

bool shouldMinifyWindow
final

Whether the window should be minimized during the snap operation.

When true, the window will minimize before snapping to the target position. When false, the window immediately snaps without minimizing.

Defaults to true.

Implementation

final bool shouldMinifyWindow;