closable property
Whether the window can be closed by the user.
When false, the close button is disabled or hidden.
Defaults to true.
Implementation
final bool closable;
Whether the window can be closed by the user.
When false, the close button is disabled or hidden.
Defaults to true.
final bool closable;