draggable property
Whether the window can be moved by dragging its title bar.
When false, the window position is fixed.
Defaults to true.
Implementation
final bool draggable;
Whether the window can be moved by dragging its title bar.
When false, the window position is fixed.
Defaults to true.
final bool draggable;