enableSnapping property
Whether edge snapping is enabled for this window.
When true, dragging the window near screen edges or regions
will trigger snap-to-edge behavior. Defaults to true.
Implementation
final bool enableSnapping;
Whether edge snapping is enabled for this window.
When true, dragging the window near screen edges or regions
will trigger snap-to-edge behavior. Defaults to true.
final bool enableSnapping;