maximizable property

bool maximizable
final

Whether the window can be maximized to fill the screen.

When false, the maximize button is disabled or hidden. Defaults to true.

Implementation

final bool maximizable;