minimizable property

bool minimizable
final

Whether the window can be minimized to the taskbar.

When false, the minimize button is disabled or hidden. Defaults to true.

Implementation

final bool minimizable;