resizable property
Whether the window can be resized by dragging its edges or corners.
When false, the window maintains a fixed size.
Defaults to true.
Implementation
final bool resizable;
Whether the window can be resized by dragging its edges or corners.
When false, the window maintains a fixed size.
Defaults to true.
final bool resizable;