WindowTheme constructor

const WindowTheme({
  1. double? titleBarHeight,
  2. double? resizeThickness,
})

Creates a window theme with optional title bar and resize border settings.

Both parameters are optional. When null, the corresponding values will fall back to theme defaults.

Implementation

const WindowTheme({this.titleBarHeight, this.resizeThickness});