actions property
Widget(s) displayed in the title bar's action area.
Usually contains window control buttons (minimize, maximize, close) or custom action buttons. Positioned on the right side of the title bar.
Implementation
final Widget? actions;
Widget(s) displayed in the title bar's action area.
Usually contains window control buttons (minimize, maximize, close) or custom action buttons. Positioned on the right side of the title bar.
final Widget? actions;