draggable property
Whether the window can be moved by dragging the title bar.
Defaults to true. Ignored when using WindowWidget.controlled.
Implementation
final bool? draggable;
Whether the window can be moved by dragging the title bar.
Defaults to true. Ignored when using WindowWidget.controlled.
final bool? draggable;