resizable property
Whether the window can be resized by dragging edges/corners.
Defaults to true. Ignored when using WindowWidget.controlled.
Implementation
final bool? resizable;
Whether the window can be resized by dragging edges/corners.
Defaults to true. Ignored when using WindowWidget.controlled.
final bool? resizable;