call method
Returns this widget (callable syntax support).
Allows using the wrapped icon as a callable function.
Implementation
Widget call() {
return this;
}
Returns this widget (callable syntax support).
Allows using the wrapped icon as a callable function.
Widget call() {
return this;
}