builder property

WrapperBuilder? builder
final

Optional builder function to wrap the child.

If wrap is true and this is provided, the child will be wrapped using this builder function. If null, the child is returned as-is.

Implementation

final WrapperBuilder? builder;