maintainStructure property

bool maintainStructure
final

Whether to maintain the widget structure across rebuilds.

When true, wraps the child in a KeyedSubtree to preserve the widget subtree identity across rebuilds. This can be useful for maintaining widget state when the wrapper's parent rebuilds. Defaults to false.

Implementation

final bool maintainStructure;