WrapperBuilder typedef

WrapperBuilder = Widget Function(BuildContext context, Widget child)

A function signature for building widgets that wrap child widgets.

Takes a BuildContext and a Widget child, returning a wrapped Widget. This allows for dynamic wrapping behavior where the wrapper can access the build context.

Implementation

typedef WrapperBuilder = Widget Function(
  BuildContext context,
  Widget child,
);