AbsoluteResizablePaneController class
Controller for resizable panes with absolute (fixed) sizing.
Manages a panel with a specific pixel size that can be adjusted through dragging or programmatic control. Size is maintained as an absolute value.
Example:
final controller = AbsoluteResizablePaneController(200);
ResizablePane(
controller: controller,
child: Container(color: Colors.blue),
)
- Inheritance
-
- Object
- ChangeNotifier
- AbsoluteResizablePaneController
- Mixed-in types
Constructors
- AbsoluteResizablePaneController(double _size, {bool collapsed = false})
- Creates an AbsoluteResizablePaneController.
Properties
- collapsed → bool
-
Whether the panel is currently collapsed.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ← double
-
no getter
- value → double
-
The current value of the object.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
collapse(
) → void -
Collapses the panel to its minimum size.
override
-
computeSize(
double paneSize, {double? minSize, double? maxSize}) → double -
Computes the actual size based on
paneSizeand optional constraints.override -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
expand(
) → void -
Expands the panel to its maximum or default size.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resize(
double newSize, double paneSize, {double? minSize, double? maxSize}) → void -
Resizes the controller to the given
newSizewithin thepaneSizebounds.override -
toString(
) → String -
A string representation of this object.
inherited
-
tryCollapse(
[PanelSibling direction = PanelSibling.both]) → bool -
Attempts to collapse the panel in the specified
direction.inherited -
tryExpand(
[PanelSibling direction = PanelSibling.both]) → bool -
Attempts to expand the panel in the specified
direction.inherited -
tryExpandSize(
double size, [PanelSibling direction = PanelSibling.both]) → bool -
Attempts to expand by
sizepixels in the specifieddirection.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited