AnimatableValue<T> constructor
AnimatableValue<T> ({
- required T start,
- required T end,
- required T lerp(
- T a,
- T b,
- double t
A class that represents an animatable value with a start and end value, and a function to interpolate between them.
The start parameter specifies the initial value of the animation.
The end parameter specifies the final value of the animation.
The lerp parameter is a function that defines how to interpolate
between the start and end values.
Implementation
AnimatableValue({required this.start, required this.end, required this.lerp});