ButtonGroupData.horizontal constructor
Creates horizontal group data with start and end multipliers.
Both top and bottom on each side use the same value.
Implementation
const ButtonGroupData.horizontal({
double start = 1.0,
double end = 1.0,
}) : topStartValue = start,
topEndValue = end,
bottomStartValue = start,
bottomEndValue = end;