ButtonStyle.outline constructor
const
ButtonStyle.outline({
- ButtonSize size = ButtonSize.normal,
- ButtonDensity density = ButtonDensity.normal,
- ButtonShape shape = ButtonShape.rectangle,
Creates an outline button style with border and no background.
Outline buttons feature a border with transparent background, providing a clear but subtle appearance for secondary actions.
Implementation
const ButtonStyle.outline({
this.size = ButtonSize.normal,
this.density = ButtonDensity.normal,
this.shape = ButtonShape.rectangle,
}) : variance = ButtonVariance.outline;