ButtonStyle.text constructor
const
ButtonStyle.text({
- ButtonSize size = ButtonSize.normal,
- ButtonDensity density = ButtonDensity.normal,
- ButtonShape shape = ButtonShape.rectangle,
Creates a text-only button style with no background or border.
Text buttons display only their text content, making them the most minimal button style for unobtrusive actions.
Implementation
const ButtonStyle.text({
this.size = ButtonSize.normal,
this.density = ButtonDensity.normal,
this.shape = ButtonShape.rectangle,
}) : variance = ButtonVariance.text;