ButtonTheme constructor
const
ButtonTheme({
- ButtonStatePropertyDelegate<
Decoration> ? decoration, - ButtonStatePropertyDelegate<
MouseCursor> ? mouseCursor, - ButtonStatePropertyDelegate<
EdgeInsetsGeometry> ? padding, - ButtonStatePropertyDelegate<
TextStyle> ? textStyle, - ButtonStatePropertyDelegate<
IconThemeData> ? iconTheme, - ButtonStatePropertyDelegate<
EdgeInsetsGeometry> ? margin,
Creates a ButtonTheme with optional style property delegates.
All parameters are optional, allowing selective override of specific style properties while leaving others to use default values.
Implementation
const ButtonTheme(
{this.decoration,
this.mouseCursor,
this.padding,
this.textStyle,
this.iconTheme,
this.margin});