ChartColorScheme class
A color scheme for charts with 5 distinct colors.
Provides colors for up to 5 different data series in charts.
- Implementers
Constructors
-
ChartColorScheme(List<
Color> chartColors) -
Creates a chart color scheme with the given colors.
const
- ChartColorScheme.single(Color color)
-
Creates a chart color scheme using a single color for all elements.
factory
Properties
- chart1 → Color
-
Color for the first chart series.
no setter
- chart2 → Color
-
Color for the second chart series.
no setter
- chart3 → Color
-
Color for the third chart series.
no setter
- chart4 → Color
-
Color for the fourth chart series.
no setter
- chart5 → Color
-
Color for the fifth chart series.
no setter
-
chartColors
→ List<
Color> -
The list of chart colors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited