ChatGroup constructor
const
ChatGroup({
- Key? key,
- required List<
Widget> children, - AxisAlignmentGeometry? alignment,
- Color? color,
- ChatBubbleType? type,
- BorderRadiusGeometry? borderRadius,
- EdgeInsetsGeometry? padding,
- BorderSide? border,
- double? spacing,
- Widget? avatarPrefix,
- Widget? avatarSuffix,
- AxisAlignmentGeometry? avatarAlignment,
- double? avatarSpacing,
Creates a ChatGroup.
Parameters:
children(List<Widget>, required): The list of chat bubbles to display.alignment(AxisAlignmentGeometry?, optional): The alignment of the chat bubbles within the group.color(Color?, optional): The background color of the chat bubbles.type(ChatBubbleType?, optional): The type of the chat bubbles.borderRadius(BorderRadiusGeometry?, optional): The border radius of the chat bubbles.padding(EdgeInsetsGeometry?, optional): The padding inside the chat bubbles.border(BorderSide?, optional): The border of the chat bubbles.spacing(double?, optional): The spacing between chat bubbles.avatarPrefix(Widget?, optional): The widget to display before the chat bubbles.avatarSuffix(Widget?, optional): The widget to display after the chat bubbles.avatarAlignment(AxisAlignmentGeometry?, optional): The alignment of the avatar.avatarSpacing(double?, optional): The spacing between the avatar and the chat bubbles.
Implementation
const ChatGroup({
super.key,
required this.children,
this.alignment,
this.color,
this.type,
this.borderRadius,
this.padding,
this.border,
this.spacing,
this.avatarPrefix,
this.avatarSuffix,
this.avatarAlignment,
this.avatarSpacing,
});