CheckboxTheme constructor
const
CheckboxTheme({})
Creates a CheckboxTheme.
All parameters are optional and will use framework defaults when null. The theme can be applied to individual checkboxes or globally through the component theme system.
Implementation
const CheckboxTheme({
this.backgroundColor,
this.activeColor,
this.borderColor,
this.size,
this.gap,
this.borderRadius,
});