copyWith method
ChipInputTheme
copyWith({
- ValueGetter<
BoxConstraints?> ? popoverConstraints, - ValueGetter<
bool?> ? useChips, - ValueGetter<
double?> ? spacing,
Creates a copy of this theme with specified properties overridden.
Each parameter function is called only if provided, allowing selective overrides while preserving existing values for unspecified properties.
Implementation
ChipInputTheme copyWith({
ValueGetter<BoxConstraints?>? popoverConstraints,
ValueGetter<bool?>? useChips,
ValueGetter<double?>? spacing,
}) {
return ChipInputTheme(
useChips: useChips == null ? this.useChips : useChips(),
spacing: spacing == null ? this.spacing : spacing(),
);
}