CircularProgressIndicatorTheme constructor
const
CircularProgressIndicatorTheme({})
Creates a CircularProgressIndicatorTheme.
All parameters are optional and can be null to use intelligent defaults based on the current theme configuration and icon context.
Example:
const CircularProgressIndicatorTheme(
color: Colors.blue,
backgroundColor: Colors.grey,
size: 32.0,
strokeWidth: 3.0,
);
Implementation
const CircularProgressIndicatorTheme({
this.color,
this.backgroundColor,
this.size,
this.strokeWidth,
});