builder property
Async builder function that provides search results based on the query.
Receives the current search query string and should return a stream of widget lists representing the filtered command results.
Implementation
final CommandBuilder builder;