DrawerOverlayEntry<T> class
Data class representing a drawer overlay entry in the stack.
Encapsulates all configuration and state needed to render a single drawer overlay, including builders, animation, theming, and positioning.
Constructors
-
DrawerOverlayEntry({required DrawerBuilder builder, required BackdropBuilder backdropBuilder, required bool modal, required BarrierBuilder barrierBuilder, required CapturedThemes? themes, required Completer<
T> completer, required OverlayPosition position, required CapturedData? data, required bool barrierDismissible, required bool useSafeArea, required AnimationController? animationController, required bool autoOpen, required BoxConstraints? constraints, required AlignmentGeometry? alignment}) - Creates a drawer overlay entry.
Properties
- alignment → AlignmentGeometry?
-
Alignment of the drawer content.
final
- animationController → AnimationController?
-
Optional external animation controller.
final
- autoOpen → bool
-
Whether to automatically open on mount.
final
- backdropBuilder → BackdropBuilder
-
Builder for backdrop transformations.
final
- barrierBuilder → BarrierBuilder
-
Builder for the modal barrier.
final
- barrierDismissible → bool
-
Whether tapping the barrier dismisses the drawer.
final
- builder → DrawerBuilder
-
Builder for drawer content.
final
-
completer
→ Completer<
T> -
Completer for the drawer result.
final
- constraints → BoxConstraints?
-
Size constraints for the drawer.
final
- data → CapturedData?
-
Captured inherited data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ GlobalKey<
DrawerEntryWidgetState< T> > -
Key for accessing the drawer entry widget state.
final
- modal → bool
-
Whether the drawer is modal.
final
- position → OverlayPosition
-
Position of the drawer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themes → CapturedThemes?
-
Captured theme data.
final
- useSafeArea → bool
-
Whether to apply safe area insets.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited