FormValueState<T> class
Holds the current value and validator for a form field.
Immutable snapshot of a form field's state used internally by form controllers to track field values and their associated validation rules.
Constructors
-
FormValueState({T? value, Validator<
T> ? validator}) - Creates a FormValueState.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override