values property
Iterable<FormattedValuePart>
get
values
Returns an iterable of only the parts that can hold values.
This excludes static parts like separators or fixed text.
Implementation
Iterable<FormattedValuePart> get values =>
parts.where((part) => part.part.canHaveValue);