GradientAngle class
A non-directional gradient angle that uses standard Alignment.
Unlike DirectionalGradientAngle, this class uses non-directional Alignment and is not affected by text direction. The angle is specified in radians.
Example:
const angle = GradientAngle(pi / 4); // 45 degrees
final begin = angle.begin;
final end = angle.end;
- Inheritance
-
- Object
- GradientAngleGeometry
- GradientAngle
Constructors
- GradientAngle(double angle)
-
Creates a GradientAngle with the specified
anglein radians.const
Properties
- angle → double
-
The angle of the gradient in radians.
final
- begin → AlignmentGeometry
-
The beginning alignment calculated from the angle.
no setteroverride
- end → AlignmentGeometry
-
The ending alignment calculated from the angle.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDirectional(
) → DirectionalGradientAngle -
Converts this to a directional gradient angle.
inherited
-
toNonDirectional(
) → GradientAngle -
Converts this to a non-directional gradient angle.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited