IconContainerTheme class
Provides themed icon container widgets for shadcn_flutter components.
Includes IconContainerTheme and IconContainer for styling icons with background, padding, and border radius.
- Inheritance
-
- Object
- ComponentThemeData
- IconContainerTheme
Constructors
- IconContainerTheme({Color? backgroundColor, Color? iconColor, EdgeInsetsGeometry? padding, BorderRadius? borderRadius})
-
Creates an IconContainerTheme.
const
Properties
- backgroundColor → Color?
-
Background color for the icon container.
final
- borderRadius → BorderRadius?
-
Border radius for the icon container.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iconColor → Color?
-
Color for the icon inside the container.
final
- padding → EdgeInsetsGeometry?
-
Padding inside the icon container.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ValueGetter< Color?> ? backgroundColor, ValueGetter<Color?> ? iconColor, ValueGetter<EdgeInsetsGeometry?> ? padding, ValueGetter<BorderRadius?> ? borderRadius}) → IconContainerTheme - Returns a copy of this theme with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override