InputCopyFeature class
Adds a copy button to the input field.
Provides a button that copies the current input text to the clipboard. Useful for allowing users to easily copy generated or displayed content.
Example:
TextField(
controller: TextEditingController(text: 'Copy me!'),
features: [
InputCopyFeature(),
],
)
- Inheritance
-
- Object
- InputFeature
- InputCopyFeature
Constructors
- InputCopyFeature({InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true, InputFeaturePosition position = InputFeaturePosition.trailing, Widget? icon})
-
Creates an InputCopyFeature.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Custom icon for the copy button.
final
- position → InputFeaturePosition
-
Position of the copy button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipFocusTraversal → bool
-
Whether to skip this feature in focus traversal.
finalinherited
- visibility → InputFeatureVisibility
-
Visibility mode for this input feature.
finalinherited
Methods
-
createState(
) → InputFeatureState< InputFeature> -
Creates the state for this input feature.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited