withValue method
Creates a copy of this part with the specified value.
Implementation
@override
/// Creates a copy of this part with the specified value.
FormattedValuePart withValue(String value) {
return FormattedValuePart(this, value);
}
Creates a copy of this part with the specified value.
@override
/// Creates a copy of this part with the specified value.
FormattedValuePart withValue(String value) {
return FormattedValuePart(this, value);
}