InputStepperButtonFeature class
Adds a single increment button to numeric input fields.
Provides a button that increases the numeric value by a fixed step.
- Inheritance
-
- Object
- InputFeature
- InputStepperButtonFeature
Constructors
- InputStepperButtonFeature({InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true, double step = 1.0, double? invalidValue = 0.0, double? min, double? max, InputFeaturePosition position = InputFeaturePosition.trailing, Widget? icon = const Icon(LucideIcons.plus)})
-
Creates an InputStepperButtonFeature.
const
- InputStepperButtonFeature.decrement({InputFeatureVisibility visibility = InputFeatureVisibility.always, bool skipFocusTraversal = true, double step = -1.0, double? invalidValue = 0.0, double? min, double? max, InputFeaturePosition position = InputFeaturePosition.trailing, Widget? icon = const Icon(LucideIcons.minus)})
-
Creates a decrement button feature for numeric inputs.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Custom icon for the increment button.
final
- invalidValue → double?
-
Default value when the input is invalid or empty.
final
- max → double?
-
Maximum allowed value.
final
- min → double?
-
Minimum allowed value.
final
- position → InputFeaturePosition
-
Position of the increment button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipFocusTraversal → bool
-
Whether to skip this feature in focus traversal.
finalinherited
- step → double
-
The amount to increment on each press.
final
- visibility → InputFeatureVisibility
-
Visibility mode for this input feature.
finalinherited
Methods
-
createState(
) → InputFeatureState< InputFeature> -
Creates the state for this input feature.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited