ListChanges<T> class
Represents a collection of list modifications.
Encapsulates multiple ListChange objects that can be applied to a list in sequence. Useful for batch operations or undo/redo functionality.
Constructors
-
ListChanges(List<
ListChange< changes)T> > -
Creates a ListChanges with the specified
changes.const
Properties
-
changes
→ List<
ListChange< T> > -
The list of individual changes to apply.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
List< T> list) → void -
Applies all changes to the given
listin order. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited