ListRemoveChange<T> class
A list change that removes an item.
Removes the item at the specified index from the list.
- Inheritance
-
- Object
- ListChange<
T> - ListRemoveChange
Constructors
- ListRemoveChange(int index)
-
Creates a ListRemoveChange that removes the item at
index.const
Properties
Methods
-
apply(
List< T> list) → void -
Applies this change to the given
list.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited