closeAll method
void
closeAll()
Closes all menus in the hierarchy by bubbling up to root.
Recursively closes popovers in parent groups and invokes the dismissal callback at the root level.
Implementation
void closeAll() {
var menuGroupData = parent;
if (menuGroupData == null) {
onDismissed?.call();
return;
}
menuGroupData.closeOthers();
menuGroupData.closeAll();
}