find<T> static method
Find the data of the given type from the context. Throws an assertion error if the data is not found.
TThe type of the data.contextThe build context.keyThe data key.
Implementation
static T find<T>(BuildContext context, Symbol key) {
return MultiModel.find(context, key);
}