ofProperty<T> static method
Find and listen to property changes of the data with the given type from the context. Throws an assertion error if the data is not found.
TThe type of the data.contextThe build context.keyThe data key.
Implementation
static ModelProperty<T> ofProperty<T>(BuildContext context, Symbol key) {
return MultiModel.ofProperty(context, key);
}