change method
Change the data of the model with the given key. Throws an assertion error if the model is read-only.
TThe type of the data.contextThe build context.- key The data key.
dataThe new data.
Implementation
void change(BuildContext context, T data) {
MultiModel.change(context, key, data);
}