find method
Find the data of the given type from the context. Throws an assertion error if the data is not found.
TThe type of the data.contextThe build context.- key The data key.
Implementation
T find(BuildContext context) {
return MultiModel.find<T>(context, key);
}