findProperty method
Find the data of the given type from the context. Throws an assertion error if the data is not found.
TThe type of the data.contextThe build context.- key The data key.
Implementation
ModelProperty<T> findProperty(BuildContext context) {
return MultiModel.findProperty<T>(context, key);
}