maybeOf method
Optionally find and listen to data changes of the data with the given type from the context.
TThe type of the data.contextThe build context.- key The data key.
Implementation
T? maybeOf(BuildContext context) {
return MultiModel.maybeOf<T>(context, key);
}