maybeOf<T> static method
Optionally find and listen to data changes of the data with the given type from the context.
TThe type of the data.contextThe build context.keyThe data key.
Implementation
static T? maybeOf<T>(BuildContext context, Symbol key) {
return maybeOfProperty<T>(context, key)?.value;
}