ObjectFormFieldDialogResult<T> class
Holds the result value from an object form field dialog.
Used to pass the selected or edited value back from a dialog prompt.
Example:
final result = ObjectFormFieldDialogResult<DateTime>(DateTime.now());
Navigator.of(context).pop(result);
Constructors
- ObjectFormFieldDialogResult(T? value)
- Creates an ObjectFormFieldDialogResult.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
The value selected or edited by the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited