PreviewLabelBuilder typedef
PreviewLabelBuilder =
Widget Function(BuildContext context, Color color)
A function that builds a preview label widget for the eye dropper.
Parameters:
context: The build context.color: The currently selected color under the cursor.
Returns: A widget to display as the color preview label.
Implementation
typedef PreviewLabelBuilder = Widget Function(
BuildContext context, Color color);