RenderChatConstrainedBox constructor
RenderChatConstrainedBox({
- required double widthFactor,
- required AxisAlignment alignment,
- RenderBox? child,
Creates a RenderChatConstrainedBox.
Parameters:
widthFactor(double, required): The fraction of the available width that the child should occupy.alignment(AxisAlignment, required): The alignment of the child within the available space.child(RenderBox?, optional): The child render object.
Implementation
RenderChatConstrainedBox({
required double widthFactor,
required AxisAlignment alignment,
RenderBox? child,
}) : _widthFactor = widthFactor,
_alignment = alignment,
super(child);