tryCollapse method
Attempts to collapse the panel in the specified direction.
Returns true if successful, false if collapse was blocked.
Implementation
bool tryCollapse([PanelSibling direction = PanelSibling.both]) {
assert(_paneState != null, 'ResizablePaneController is not attached');
return _paneState!.tryCollapse(direction);
}