tryExpand method
Attempts to expand the panel in the specified direction.
Returns true if successful, false if expansion was blocked.
Implementation
bool tryExpand([PanelSibling direction = PanelSibling.both]) {
assert(_paneState != null, 'ResizablePaneController is not attached');
return _paneState!.tryExpand(direction);
}