tryExpandSize method
Attempts to expand by size pixels in the specified direction.
Returns true if successful, false if expansion was blocked.
Implementation
bool tryExpandSize(double size,
[PanelSibling direction = PanelSibling.both]) {
assert(_paneState != null, 'ResizablePaneController is not attached');
return _paneState!.tryExpandSize(size, direction);
}