ScrollableClientTheme class
Theme data for ScrollableClient.
- Inheritance
-
- Object
- ComponentThemeData
- ScrollableClientTheme
Constructors
- ScrollableClientTheme({DiagonalDragBehavior? diagonalDragBehavior, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, Clip? clipBehavior, HitTestBehavior? hitTestBehavior, bool? overscroll})
-
Creates a ScrollableClientTheme.
const
Properties
- clipBehavior → Clip?
-
How to clip the scrollable content.
final
- diagonalDragBehavior → DiagonalDragBehavior?
-
Behavior for diagonal drag gestures.
final
- dragStartBehavior → DragStartBehavior?
-
When drag gestures should start.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hitTestBehavior → HitTestBehavior?
-
How hit testing should behave for the scrollable.
final
- keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior?
-
How the keyboard dismissal should behave.
final
- overscroll → bool?
-
Whether overscroll effects are enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ValueGetter< DiagonalDragBehavior?> ? diagonalDragBehavior, ValueGetter<DragStartBehavior?> ? dragStartBehavior, ValueGetter<ScrollViewKeyboardDismissBehavior?> ? keyboardDismissBehavior, ValueGetter<Clip?> ? clipBehavior, ValueGetter<HitTestBehavior?> ? hitTestBehavior, ValueGetter<bool?> ? overscroll}) → ScrollableClientTheme - Creates a copy of this theme with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override