SheetConfiguration<T> class
OverlayConfiguration that presents its content as a minimally-styled, full-extent sheet (no backdrop transform, unlike DrawerConfiguration).
Already the mobile-appropriate mechanism, so adaptiveConversion is the identity conversion (no adaptation performed).
- Inheritance
-
- Object
- OverlayConfiguration<
T> - SheetConfiguration
Constructors
- SheetConfiguration({Anchor? anchor, required WidgetBuilder builder, OverlayPosition position = OverlayPosition.bottom, bool barrierDismissible = true, bool transformBackdrop = false, WidgetBuilder? backdropBuilder, Color? barrierColor, bool draggable = false, AnimationController? animationController, bool autoOpen = true, BoxConstraints? constraints, AlignmentGeometry? alignment})
-
Creates a SheetConfiguration.
const
Properties
- alignment → AlignmentGeometry?
-
Alignment within constraints.
final
- anchor → Anchor?
-
The Anchor to resolve against (LinkedAnchor for an anchor key
registered via OverlayAnchor, or ContextAnchor), if using
anchor-based positioning instead of the BuildContext passed to show.
final
- animationController → AnimationController?
-
Custom animation controller.
final
- autoOpen → bool
-
Whether to automatically open on creation.
final
- backdropBuilder → WidgetBuilder?
-
Custom backdrop builder.
final
- barrierColor → Color?
-
Color of the modal barrier.
final
- barrierDismissible → bool
-
Whether tapping the barrier dismisses the sheet.
final
- builder → WidgetBuilder
-
Builds the sheet content.
final
- constraints → BoxConstraints?
-
Size constraints for the sheet.
final
- draggable → bool
-
Whether the sheet can be dragged to dismiss.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → OverlayPosition
-
The edge the sheet slides in from.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transformBackdrop → bool
-
Whether to transform the backdrop.
final
Methods
-
adaptiveConversion(
BuildContext context) → OverlayConfiguration< T> -
Returns an equivalent configuration adapted for the current platform,
e.g. a PopoverConfiguration becomes a DrawerConfiguration on mobile.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
BuildContext context) → OverlayCompleter< T?> -
Actually presents the overlay using this configuration's mechanism.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited