decreaseStep property
The step size for keyboard decrement actions.
Used when the user triggers decrease actions via keyboard. If null,
a default step is calculated based on the slider range.
Implementation
final double? decreaseStep;
The step size for keyboard decrement actions.
Used when the user triggers decrease actions via keyboard. If null,
a default step is calculated based on the slider range.
final double? decreaseStep;