increaseStep property
The step size for keyboard increment actions.
Used when the user triggers increase actions via keyboard. If null,
a default step is calculated based on the slider range.
Implementation
final double? increaseStep;
The step size for keyboard increment actions.
Used when the user triggers increase actions via keyboard. If null,
a default step is calculated based on the slider range.
final double? increaseStep;