child property
The main child widget that will be made sortable.
Type: Widget. This widget is displayed normally and becomes draggable
when drag interactions are initiated.
Implementation
final Widget child;
The main child widget that will be made sortable.
Type: Widget. This widget is displayed normally and becomes draggable
when drag interactions are initiated.
final Widget child;