SortableChildListDelegate<T> class
A delegate that provides items from an explicit list.
Wraps a fixed List of items for use in a sortable list.
- Inheritance
-
- Object
- SortableListDelegate<
T> - SortableChildListDelegate
Constructors
-
SortableChildListDelegate(List<
T> items, SortableWidgetBuilder<T> builder) -
Creates a SortableChildListDelegate.
const
Properties
-
builder
→ SortableWidgetBuilder<
T> -
Builder for creating item widgets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemCount → int
-
The number of items in the list.
no setteroverride
-
items
→ List<
T> -
The list of items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getItem(
BuildContext context, int index) → T -
Retrieves the item at the specified
index.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited