child property
The child widget that serves as the drag handle.
Type: Widget. This widget defines the visual appearance of the drag handle
and responds to drag gestures. Commonly an icon like Icons.drag_handle.
Implementation
final Widget child;
The child widget that serves as the drag handle.
Type: Widget. This widget defines the visual appearance of the drag handle
and responds to drag gestures. Commonly an icon like Icons.drag_handle.
final Widget child;