enabled property
Whether the drag handle is enabled for drag operations.
Type: bool, default: true. When false, the handle will not respond to
drag gestures and shows the default cursor instead of grab cursors.
Implementation
final bool enabled;
Whether the drag handle is enabled for drag operations.
Type: bool, default: true. When false, the handle will not respond to
drag gestures and shows the default cursor instead of grab cursors.
final bool enabled;