canAccept property
Predicate to determine if dropped data can be accepted by this fallback zone.
Type: Predicate<SortableData<T>>?. If null, all sortable items are accepted.
Return true to accept the drop, false to reject it.
Implementation
final Predicate<SortableData<T>>? canAccept;