StillKeyframe<T> constructor
const
StillKeyframe<T> (
- Duration duration, [
- T? value
Creates a still keyframe that holds a value.
Parameters
duration- How long to hold the value.value- The value to hold, ornullto use the previous keyframe's end value.
Notes
If value is null, this keyframe must not be the first in the timeline.
Implementation
const StillKeyframe(this.duration, [this.value]);