onSelect property
Callback to invoke when this tab should be selected.
Called with the tab's index when the user interacts with the tab.
Implementation
final ValueChanged<int>? onSelect;
Callback to invoke when this tab should be selected.
Called with the tab's index when the user interacts with the tab.
final ValueChanged<int>? onSelect;