TableHeader class
Specialized row for table headers.
Extends TableRow with default styling appropriate for header rows, including bold text, muted background, and bottom border styling.
Example:
TableHeader(
cells: [
TableCell(child: Text('Name')),
TableCell(child: Text('Age')),
TableCell(child: Text('City')),
],
)
Constructors
-
TableHeader({required List<
TableCell> cells, TableCellTheme? cellTheme}) -
Creates a TableHeader.
const
Properties
-
cells
→ List<
TableCell> -
The cells contained in this row.
finalinherited
- cellTheme → TableCellTheme?
-
Theme applied to all cells in this row.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether this row is selected.
finalinherited
Methods
-
buildDefaultTheme(
BuildContext context) → TableCellTheme -
Builds the default theme for cells in this row.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited