TableParentData class
Parent data for table cell layout information.
Stores layout parameters for cells in a table including position, span, and frozen state. Used internally by the table rendering system.
- Inheritance
-
- Object
- ParentData
- BoxParentData
- ContainerBoxParentData<
RenderBox> - TableParentData
Constructors
Properties
- column ↔ int?
-
Column index of this cell.
getter/setter pair
- columnSpan ↔ int?
-
Number of columns this cell spans.
getter/setter pair
- computeSize ↔ bool
-
Whether to compute size for this cell.
getter/setter pair
- frozenColumn ↔ bool
-
Whether this cell's column is frozen.
getter/setter pair
- frozenRow ↔ bool
-
Whether this cell's row is frozen.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextSibling ↔ RenderBox?
-
The next sibling in the parent's child list.
getter/setter pairinherited
- offset ↔ Offset
-
The offset at which to paint the child in the parent's coordinate system.
getter/setter pairinherited
- previousSibling ↔ RenderBox?
-
The previous sibling in the parent's child list.
getter/setter pairinherited
- row ↔ int?
-
Row index of this cell.
getter/setter pair
- rowSpan ↔ int?
-
Number of rows this cell spans.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detach(
) → void -
Clear the sibling pointers.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited