TimeRange class
Represents a range of time with a start and end time.
Used to define time intervals or periods. Both start and end are represented as TimeOfDay values.
Example:
final workHours = TimeRange(
start: TimeOfDay(hour: 9, minute: 0),
end: TimeOfDay(hour: 17, minute: 0),
);
Constructors
Properties
Methods
-
copyWith(
{ValueGetter< TimeOfDay> ? start, ValueGetter<TimeOfDay> ? end}) → TimeRange - Creates a copy of this range with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override