Transformers class abstract
A utility class that provides static methods for transforming various types of values, such as numbers, colors, offsets, and sizes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
typeColor(
Color? a, Color? b, double t) → Color? -
Interpolates between two colors
aandbbased on the given factort. -
typeDouble(
double? a, double? b, double t) → double? -
Interpolates between two double values
aandbbased on the given interpolation factort. -
typeInt(
int? a, int? b, double t) → int? -
Interpolates between two integer values
aandbbased on the given factort. -
typeOffset(
Offset? a, Offset? b, double t) → Offset? -
Interpolates between two Offset values,
aandb, based on the given interpolation factort. -
typeSize(
Size? a, Size? b, double t) → Size? -
Interpolates between two Size objects,
aandb, based on the given interpolation factort.