alwaysOnTop property
bool
get
alwaysOnTop
Whether the window always appears on top of other windows.
Implementation
bool get alwaysOnTop => value.alwaysOnTop;
set
alwaysOnTop
(bool value)
Sets the always-on-top behavior.
When true, the window renders above other windows regardless of focus.
Implementation
set alwaysOnTop(bool value) {
if (value == alwaysOnTop) return;
this.value = this.value.copyWith(alwaysOnTop: () => value);
}