maximized property
Bounds of the window when maximized, or null if not maximized.
When non-null, indicates the window is in maximized state and stores the previous bounds for restoration when un-maximizing.
Implementation
final Rect? maximized;
Bounds of the window when maximized, or null if not maximized.
When non-null, indicates the window is in maximized state and stores the previous bounds for restoration when un-maximizing.
final Rect? maximized;