minimized property
Whether the window is currently minimized to the taskbar.
When true, the window is hidden from view but remains in memory.
Defaults to false.
Implementation
final bool minimized;
Whether the window is currently minimized to the taskbar.
When true, the window is hidden from view but remains in memory.
Defaults to false.
final bool minimized;