WrappedTextDataBuilder<T> typedef
WrappedTextDataBuilder<T> =
T Function(BuildContext context, ThemeData theme)
Function signature for building data from context and theme.
Used by WrappedText to compute style properties dynamically.
Type parameter T is the return type of the builder function.
Implementation
typedef WrappedTextDataBuilder<T> = T Function(
BuildContext context, ThemeData theme);